%  xml - constructor for an xml-object   
%   
%  CALL:   
%   obj = xml(FileName,isNameSpaceAware,isValidating)   
%   
%  INPUT:   
%   FileName:         <string> name of the sourcefile   
%                     <string> the xml string   
%                     <java-object> with a D(ocument) (O)bject (M)odel   
%                     <struct> a Matlab structure   
%   isNameSpaceAware: <boolean> (optional) (default == 1) ignore namespaces   
%   isValidating:     <boolean> (optional) (default == 0) validate document   
%   
%  OUTPUT:   
%   obj: <xml-object> with fields:   
%                     - DOM:  <java object> the DOM object   
%                     - file: <string> the name of the xml source   
%                     - NS:   <java object> a hashmap with namespace   
%                                           definitions   
%                     N.B. obj is empty when an error occurred   
%   
%  EXAMPLE:   
%   %create an xml from a sourcefile   
%   obj = xml(fullfile(pwd,'examples','books.xml'))   
%   inspect(obj)   
%   
%   %create an xml from a sourcefile   
%   obj = xml(java.io.File(fullfile(pwd,'examples','books.xml')))   
%   inspect(obj)   
%   
%   %create an xml from a Matlab structure   
%   obj = xml(dir)   
%   inspect(obj)   
%   
%   %create an xml directly from a string   
%   str = '<book category="MATHS"><title lang="en">Nonlinear Programming</title><author>Dimitri P. Bertsekas</author></book>'   
%   obj = xml(str)   
%   inspect(obj)   
%   
%   %create an xml directly from an inputstream   
%   obj = xml(java.io.FileInputStream((fullfile(pwd,'examples','books.xml'))))   
%   inspect(obj)   
%   
%   %create an xml from a sourcefile and validate against a dtd (specified   
%   %in the xml itself   
%   obj = xml(fullfile(pwd,'examples','note_dtd.xml'),0,1)   
%   
%   %create an xml from a sourcefile and validate against a xsd (specified   
%   %in the xml itself   
%   obj = xml(fullfile(pwd,'examples','note_xsd.xml'),1,1)   
%   
%  See also: xml/view, xml/inspect   
   
%   Copyright 2006-2011 Modelit (www.modelit.nl)   
%   Revision: 1.07   
%   Date: 2011-08-01 11:43:58   
