% struct2xmlstr - Fast and simple way to create xml strings from Matlab   
%                 structure. Equivalent to xml2str(xml(S)), but faster.   
%   
%  CALL   
%      str=struct2xmlstr(S)   
%      str=struct2xmlstr(S,rootname)   
%      str=struct2xmlstr(S,rootname,FLOATFORMAT)   
%      str=struct2xmlstr(S,'',FLOATFORMAT)   
%   
%  INPUT   
%      S   
%          Matlab structure.   
%      rootname   
%          parameter tag to be included as root   
%      FLOATFORMAT   
%          formatstring to be used by sprintf to convert non-integer numeric   
%          parameters to character array. Default value: '%f'. Examples of   
%          other values: '%.10g';'%.8f'. Any digits beyond specified   
%          precision will be lost.   
%   
%  OUTPUT   
%      str (1xN char array)   
%          Matlab char array that contains xml representation of S   
%   
%  NOTES   
%      This is function is useful for conversion of simple Matlab structures   
%      to XML strings. However it supports only a limited number of   
%      properties.   
%   
%  EXAMPLES   
%      struct2xmlstr(S)   
%      struct2xmlstr(S,'','%.10g')   
%      struct2xmlstr(S,'','%.8f')   
   
%   Copyright 2006-2011 Modelit (www.modelit.nl)   
%   Revision: 1.07   
%   Date: 2011-08-01 11:43:58   
